@@ -10,7 +10,7 @@ Created on Oct 10, 2011
 
 from dtrace import DTraceConsumer
 
-SCRIPT = 'syscall:::entry { @num[execname] = count(); }'
+SCRIPT = 'syscall:::entry { @num[pid,execname] = count(); }'
 
 
 def main():
@@ -18,7 +18,7 @@ def main():
     Run DTrace...
     '''
     consumer = DTraceConsumer()
-    consumer.run_script(SCRIPT, 4)
+    consumer.run_script(SCRIPT, 2)
 
 if __name__ == '__main__':
     main()
